From: David Howells <dhowells@redhat.com>
To: Jens Axboe <axboe@kernel.dk>, Al Viro <viro@zeniv.linux.org.uk>,
Christoph Hellwig <hch@infradead.org>
Cc: David Howells <dhowells@redhat.com>,
Matthew Wilcox <willy@infradead.org>, Jan Kara <jack@suse.cz>,
Jeff Layton <jlayton@kernel.org>,
David Hildenbrand <david@redhat.com>,
Jason Gunthorpe <jgg@nvidia.com>,
Logan Gunthorpe <logang@deltatee.com>,
Hillf Danton <hdanton@sina.com>,
Christian Brauner <brauner@kernel.org>,
Linus Torvalds <torvalds@linux-foundation.org>,
linux-fsdevel@vger.kernel.org, linux-block@vger.kernel.org,
linux-kernel@vger.kernel.org, linux-mm@kvack.org,
Christoph Hellwig <hch@lst.de>,
linux-erofs@lists.ozlabs.org, linux-ext4@vger.kernel.org,
linux-xfs@vger.kernel.org
Subject: [PATCH v21 08/30] splice: Make splice from a DAX file use copy_splice_read()
Date: Sat, 20 May 2023 01:00:27 +0100 [thread overview]
Message-ID: <20230520000049.2226926-9-dhowells@redhat.com> (raw)
In-Reply-To: <20230520000049.2226926-1-dhowells@redhat.com>
Make a read splice from a DAX file go directly to copy_splice_read() to do
the reading as filemap_splice_read() is unlikely to find any pagecache to
splice.
I think this affects only erofs, Ext2, Ext4, fuse and XFS.
Signed-off-by: David Howells <dhowells@redhat.com>
cc: Christoph Hellwig <hch@lst.de>
cc: Al Viro <viro@zeniv.linux.org.uk>
cc: Jens Axboe <axboe@kernel.dk>
cc: linux-erofs@lists.ozlabs.org
cc: linux-ext4@vger.kernel.org
cc: linux-xfs@vger.kernel.org
cc: linux-fsdevel@vger.kernel.org
cc: linux-block@vger.kernel.org
cc: linux-mm@kvack.org
---
Notes:
ver #21)
- Don't need #ifdef CONFIG_FS_DAX as IS_DAX() is false if !CONFIG_FS_DAX.
- Needs to be in vfs_splice_read(), not generic_file_splice_read().
fs/splice.c | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/fs/splice.c b/fs/splice.c
index 76126b1aafcb..8268248df3a9 100644
--- a/fs/splice.c
+++ b/fs/splice.c
@@ -908,10 +908,10 @@ long vfs_splice_read(struct file *in, loff_t *ppos,
if (unlikely(!in->f_op->splice_read))
return warn_unsupported(in, "read");
/*
- * O_DIRECT doesn't deal with the pagecache, so we allocate a buffer,
- * copy into it and splice that into the pipe.
+ * O_DIRECT and DAX don't deal with the pagecache, so we allocate a
+ * buffer, copy into it and splice that into the pipe.
*/
- if ((in->f_flags & O_DIRECT))
+ if ((in->f_flags & O_DIRECT) || IS_DAX(in->f_mapping->host))
return copy_splice_read(in, ppos, pipe, len, flags);
return in->f_op->splice_read(in, ppos, pipe, len, flags);
}
WARNING: multiple messages have this Message-ID (diff)
From: David Howells <dhowells@redhat.com>
To: Jens Axboe <axboe@kernel.dk>, Al Viro <viro@zeniv.linux.org.uk>,
Christoph Hellwig <hch@infradead.org>
Cc: linux-erofs@lists.ozlabs.org, linux-block@vger.kernel.org,
Hillf Danton <hdanton@sina.com>, Jan Kara <jack@suse.cz>,
linux-xfs@vger.kernel.org, David Hildenbrand <david@redhat.com>,
Linus Torvalds <torvalds@linux-foundation.org>,
Jeff Layton <jlayton@kernel.org>,
Christian Brauner <brauner@kernel.org>,
Matthew Wilcox <willy@infradead.org>,
linux-kernel@vger.kernel.org, David Howells <dhowells@redhat.com>,
linux-mm@kvack.org, Jason Gunthorpe <jgg@nvidia.com>,
linux-fsdevel@vger.kernel.org, linux-ext4@vger.kernel.org,
Logan Gunthorpe <logang@deltatee.com>,
Christoph Hellwig <hch@lst.de>
Subject: [PATCH v21 08/30] splice: Make splice from a DAX file use copy_splice_read()
Date: Sat, 20 May 2023 01:00:27 +0100 [thread overview]
Message-ID: <20230520000049.2226926-9-dhowells@redhat.com> (raw)
In-Reply-To: <20230520000049.2226926-1-dhowells@redhat.com>
Make a read splice from a DAX file go directly to copy_splice_read() to do
the reading as filemap_splice_read() is unlikely to find any pagecache to
splice.
I think this affects only erofs, Ext2, Ext4, fuse and XFS.
Signed-off-by: David Howells <dhowells@redhat.com>
cc: Christoph Hellwig <hch@lst.de>
cc: Al Viro <viro@zeniv.linux.org.uk>
cc: Jens Axboe <axboe@kernel.dk>
cc: linux-erofs@lists.ozlabs.org
cc: linux-ext4@vger.kernel.org
cc: linux-xfs@vger.kernel.org
cc: linux-fsdevel@vger.kernel.org
cc: linux-block@vger.kernel.org
cc: linux-mm@kvack.org
---
Notes:
ver #21)
- Don't need #ifdef CONFIG_FS_DAX as IS_DAX() is false if !CONFIG_FS_DAX.
- Needs to be in vfs_splice_read(), not generic_file_splice_read().
fs/splice.c | 6 +++---
1 file changed, 3 insertions(+), 3 deletions(-)
diff --git a/fs/splice.c b/fs/splice.c
index 76126b1aafcb..8268248df3a9 100644
--- a/fs/splice.c
+++ b/fs/splice.c
@@ -908,10 +908,10 @@ long vfs_splice_read(struct file *in, loff_t *ppos,
if (unlikely(!in->f_op->splice_read))
return warn_unsupported(in, "read");
/*
* O_DIRECT doesn't deal with the pagecache, so we allocate a buffer,
* copy into it and splice that into the pipe.
*/
- if ((in->f_flags & O_DIRECT))
+ if ((in->f_flags & O_DIRECT) || IS_DAX(in->f_mapping->host))
return copy_splice_read(in, ppos, pipe, len, flags);
return in->f_op->splice_read(in, ppos, pipe, len, flags);
}
next prev parent reply other threads:[~2023-05-20 0:03 UTC|newest]
Thread overview: 85+ messages / expand[flat|nested] mbox.gz Atom feed top
2023-05-20 0:00 [PATCH v21 00/30] splice: Kill ITER_PIPE David Howells
2023-05-20 0:00 ` [PATCH v21 01/30] splice: Fix filemap of a blockdev David Howells
2023-05-20 4:08 ` Christoph Hellwig
2023-05-20 9:14 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 02/30] splice: Make filemap_splice_read() check s_maxbytes David Howells
2023-05-20 4:09 ` Christoph Hellwig
2023-05-20 9:21 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 03/30] splice: Rename direct_splice_read() to copy_splice_read() David Howells
2023-05-20 4:09 ` Christoph Hellwig
2023-05-20 9:23 ` Christian Brauner
2023-05-20 9:51 ` David Howells
2023-05-22 7:55 ` David Howells
2023-05-22 12:53 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 04/30] splice: Clean up copy_splice_read() a bit David Howells
2023-05-20 9:34 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 05/30] splice: Make do_splice_to() generic and export it David Howells
2023-05-20 9:35 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 06/30] splice: Check for zero count in vfs_splice_read() David Howells
2023-05-20 9:38 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 07/30] splice: Make splice from an O_DIRECT fd use copy_splice_read() David Howells
2023-05-20 4:11 ` Christoph Hellwig
2023-05-20 9:39 ` Christian Brauner
2023-05-20 0:00 ` David Howells [this message]
2023-05-20 0:00 ` [PATCH v21 08/30] splice: Make splice from a DAX file " David Howells
2023-05-20 4:11 ` Christoph Hellwig
2023-05-20 4:11 ` Christoph Hellwig
2023-05-20 9:41 ` Christian Brauner
2023-05-20 9:41 ` Christian Brauner
2023-05-21 0:28 ` Theodore Ts'o
2023-05-21 0:28 ` Theodore Ts'o
2023-05-21 14:55 ` Gao Xiang
2023-05-21 14:55 ` Gao Xiang
2023-05-20 0:00 ` [PATCH v21 09/30] shmem: Implement splice-read David Howells
2023-05-20 0:00 ` [PATCH v21 10/30] overlayfs: " David Howells
2023-05-20 9:47 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 11/30] coda: " David Howells
2023-05-20 0:00 ` [PATCH v21 12/30] tty, proc, kernfs, random: Use copy_splice_read() David Howells
2023-05-20 0:00 ` [PATCH v21 13/30] net: Make sock_splice_read() use copy_splice_read() by default David Howells
2023-05-20 0:00 ` [PATCH v21 14/30] 9p: Add splice_read stub David Howells
2023-05-20 0:00 ` [PATCH v21 15/30] afs: Provide a splice-read stub David Howells
2023-05-20 0:00 ` [PATCH v21 16/30] ceph: " David Howells
2023-05-22 2:12 ` Xiubo Li
2023-05-20 0:00 ` [PATCH v21 17/30] ecryptfs: " David Howells
2023-05-20 0:00 ` [PATCH v21 18/30] ext4: " David Howells
2023-05-20 4:12 ` Christoph Hellwig
2023-05-20 7:21 ` David Howells
2023-05-20 9:01 ` Christoph Hellwig
2023-05-21 0:26 ` Theodore Ts'o
2023-05-20 0:00 ` [PATCH v21 19/30] f2fs: " David Howells
2023-05-20 0:00 ` [f2fs-dev] " David Howells
2023-07-06 0:18 ` patchwork-bot+f2fs
2023-07-06 0:18 ` patchwork-bot+f2fs
2023-05-20 0:00 ` [PATCH v21 20/30] nfs: " David Howells
2023-05-20 0:00 ` [PATCH v21 21/30] ntfs3: " David Howells
2023-05-20 0:00 ` [PATCH v21 22/30] ocfs2: " David Howells
2023-05-20 0:00 ` [Ocfs2-devel] " David Howells via Ocfs2-devel
2023-05-22 2:49 ` Joseph Qi
2023-05-22 2:49 ` [Ocfs2-devel] " Joseph Qi via Ocfs2-devel
2023-05-22 6:28 ` David Howells
2023-05-22 6:28 ` [Ocfs2-devel] " David Howells via Ocfs2-devel
2023-05-22 6:34 ` Joseph Qi
2023-05-22 6:34 ` [Ocfs2-devel] " Joseph Qi via Ocfs2-devel
2023-05-22 6:49 ` David Howells
2023-05-22 6:49 ` [Ocfs2-devel] " David Howells via Ocfs2-devel
2023-05-22 6:54 ` Joseph Qi
2023-05-22 6:54 ` [Ocfs2-devel] " Joseph Qi via Ocfs2-devel
2023-05-20 0:00 ` [PATCH v21 23/30] orangefs: " David Howells
2023-05-20 0:00 ` [PATCH v21 24/30] xfs: " David Howells
2023-05-20 4:13 ` Christoph Hellwig
2023-05-20 0:00 ` [PATCH v21 25/30] zonefs: " David Howells
2023-05-20 0:00 ` [PATCH v21 26/30] splice: Convert trace/seq to use copy_splice_read() David Howells
2023-05-20 4:14 ` Christoph Hellwig
2023-05-21 10:28 ` Masami Hiramatsu
2023-05-21 12:50 ` David Howells
2023-05-23 14:27 ` Steven Rostedt
2023-05-20 0:00 ` [PATCH v21 27/30] cifs: Use filemap_splice_read() David Howells
2023-05-20 0:00 ` [PATCH v21 28/30] splice: Use filemap_splice_read() instead of generic_file_splice_read() David Howells
2023-05-20 4:14 ` Christoph Hellwig
2023-05-20 9:56 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 29/30] splice: Remove generic_file_splice_read() David Howells
2023-05-20 4:14 ` Christoph Hellwig
2023-05-20 9:57 ` Christian Brauner
2023-05-20 0:00 ` [PATCH v21 30/30] iov_iter: Kill ITER_PIPE David Howells
2023-05-20 4:15 ` Christoph Hellwig
2023-05-20 9:58 ` Christian Brauner
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20230520000049.2226926-9-dhowells@redhat.com \
--to=dhowells@redhat.com \
--cc=axboe@kernel.dk \
--cc=brauner@kernel.org \
--cc=david@redhat.com \
--cc=hch@infradead.org \
--cc=hch@lst.de \
--cc=hdanton@sina.com \
--cc=jack@suse.cz \
--cc=jgg@nvidia.com \
--cc=jlayton@kernel.org \
--cc=linux-block@vger.kernel.org \
--cc=linux-erofs@lists.ozlabs.org \
--cc=linux-ext4@vger.kernel.org \
--cc=linux-fsdevel@vger.kernel.org \
--cc=linux-kernel@vger.kernel.org \
--cc=linux-mm@kvack.org \
--cc=linux-xfs@vger.kernel.org \
--cc=logang@deltatee.com \
--cc=torvalds@linux-foundation.org \
--cc=viro@zeniv.linux.org.uk \
--cc=willy@infradead.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -908,10 +908,10 @@ long vfs_splice_read(struct file *in, loff_t *ppos,
return warn_unsupported(in, "read");
/*
- * O_DIRECT doesn't deal with the pagecache, so we allocate a buffer,
- * copy into it and splice that into the pipe.
+ * O_DIRECT and DAX don't deal with the pagecache, so we allocate a
+ * buffer, copy into it and splice that into the pipe.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.